AnimatedGrid<T> class

Inheritance

Constructors

AnimatedGrid({Key? key, required double itemHeight, required List<T> items, required Key keyBuilder(T item), required AnimatedGridBuilder<T> builder, double padding = 8, int columns = 2, Duration duration = const Duration(milliseconds: 500), Curve curve = Curves.elasticOut})
An animated grid the animates when the items change sort.
const

Properties

builder → AnimatedGridBuilder<T>
Build a widget given a context, the current item, and the column and row index.
final
columns → int
The number of columns wide to display.
final
curve → Curve
The curve of the sort animation.
final
duration → Duration
The duration of the sort animation.
final
hashCode → int
The hash code for this object.
no setterinherited
itemHeight → double
The height of each child.
final
items → List<T>
The grid items. Should all be the same height.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyBuilder → Key Function(T item)
Construct keys given the item provided. Each key must be unique.
final
padding → double
The height of each child.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

gridIndicies(int index, int columns, int count) → List<int>