TabSwitcherTab class abstract

Constructors

TabSwitcherTab()

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
no setter
key → Key
no setter
previewImage ↔ Image?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(TabState state) → Widget
getContent() → Widget
getSubtitle() → String?
getTitle() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSave(TabState state) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited